;;; Gash -- Guile As SHell
;;;
;;; This file is part of Gash.
;;;
;;; Gash is free software: you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation, either version 3 of the License, or
;;; (at your option) any later version.
;;;
;;; Gash is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with Gash.  If not, see <http://www.gnu.org/licenses/>.

(define-module (test-lang-spec)
  #:use-module (ice-9 eval-string)
  #:use-module (srfi srfi-64)
  #:use-module (tests unit automake))

;;; Commentary:
;;;
;;; Tests for (language sh spec) module.
;;;
;;; Code:


(test-begin "lang")

(test-eq "Exit code 0"
  0
  (eval-string "true" #:lang 'sh))

(test-eq "Exit code 1"
  1
  (eval-string "false" #:lang 'sh))


(test-equal "Builtin echo"
  "foo\n"
  (with-output-to-string (lambda () (eval-string "echo foo" #:lang 'sh))))

(test-assert "external"
  (with-output-to-string (lambda () (eval-string "set -e; ls" #:lang 'sh))))

(test-end "lang")
